@@ -9,17 +9,22 @@
 #' @importFrom plyr join_all
 
 #' @examples
-#' ### Do not run
-#' ### EXAMPLE =  wTO.Complete( k =1, n = 200, Data = ExampledfExpression,
-#' ### Overlap = ExampleGRF$x, method = "p")
-#' ### Do not run
-#' ### NetVis(EXAMPLE$wTO, cutoff= list(kind = "Threshold", value = 0.55),
-#' ### layout = "layout_in_circle")
-#' ### Selection of only the significative ones for the Consensus
-#' ### Ex_k1_cor_p_boot_p005_sig = subset(EXAMPLE$wTO, EXAMPLE$wTO$pval < 0.05)
-#' ### Ex_k1_cor_p_boot_p005_abs = subset(EXAMPLE$abs.wTO, EXAMPLE$abs.wTO$pval < 0.05)
-#' ### Constructing the consensus network
-#' #CONS = wTO.Consensus(data = list(Ex_k1_cor_p_boot_p005_sig, Ex_k1_cor_p_boot_p005_abs))
+#' \dontrun{
+#'EXAMPLE =  wTO.Complete( k =1, n = 200, Data = ExampledfExpression,
+#'                                       Overlap = ExampleGRF$x, method = "p")
+#'
+#' #Selection of only the significative ones for the Consensus
+#' Ex_k1_cor_p_boot_p005_sig = subset(EXAMPLE$wTO,
+#' EXAMPLE$wTO$pval_sig < 0.05,
+#' select = c("Node.1", "Node.2", "wTO_sign"))
+#' Ex_k1_cor_p_boot_p005_abs = subset(EXAMPLE$wTO,
+#' EXAMPLE$wTO$pval_abs < 0.05,
+#' select = c("Node.1", "Node.2", "wTO_abs"))
+#' # Constructing the consensus network
+#' CONS = wTO.Consensus(data = list(Ex_k1_cor_p_boot_p005_sig,
+#' Ex_k1_cor_p_boot_p005_abs))
+#' }
+
 
 wTO.Consensus = function(data, full = FALSE){
   if (!is.list(data)){
@@ -43,13 +48,17 @@ wTO.Consensus = function(data, full = FALSE){
                              type = "full")
   }
   data_xx = subset(data_xx, data_xx$Node.1 %in% Nodes$ID & data_xx$Node.2 %in% Nodes$ID)
+  wTO_NA = apply(data_xx[, -c(1, 2)], 1, function(x) sum(is.na(x)))
+  wTO_NA = wTO_NA/ ncol(data_xx[, -c(1, 2)])
   data_xx[is.na(data_xx)] <- 0
   data_x = data_xx[, -c(1, 2)]
   abs_x = apply(data_x, 2, abs)
   sum_abs_x = apply(abs_x, 1, sum)
   div = (abs_x/sum_abs_x) * data_x
   wTO_cons = apply(div, 1, sum)
-  cons_wto = data.frame(Node.1 = data_xx$Node.1, Node.2 = data_xx$Node.2,
-                        wTO_Cons = wTO_cons)
-  return(data.table::data.table(cons_wto))
+
+  cons_wto = data.table::data.table(data.frame(Node.1 = data_xx$Node.1, Node.2 = data_xx$Node.2,
+                        wTO_Cons = wTO_cons), prop.NA = wTO_NA)
+  class(cons_wto)<- append('wTOCN', class(cons_wto))
+  return(cons_wto)
 }
